## 1.2.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 1.2.0.20240219 (2024-02-19)

[stubsabot] Bump netaddr to 1.2.* (#11437)

Co-authored-by: stubsabot <>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.1.0.20240218 (2024-02-18)

[stubsabot] Bump netaddr to 1.1.* (#11424)

Co-authored-by: stubsabot <>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 1.0.0.20240212 (2024-02-12)

netaddr: Bump to version 1.0 (#11401)

Closes #11395

## 0.10.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 0.10.0.20240102 (2024-01-02)

netaddr: Bump to 0.10.* (#11215)

Closes #11211

## 0.9.0.2 (2023-12-19)

Review `SupportsInt` and `SupportsFloat` usages in 3rd-party stubs (#11003)

## 0.9.0.1 (2023-09-23)

stdlib/xml/sax: Add type annotations (#10606)

* stdlib/xml/sax: Type annotations for commonly used methods.

* stdlib/xml/sax: More annotations.

It turns out SAX's definition of a "qname" is exactly the opposite of
ElementTree's. With that understanding, let's annotate the Attributes*Impl
classes too.

* stdlib/xml/sax: I better understand what AttributesNSImpl is doing now.

* Update third-party library stubs to agree with the new SAX annotations.

## 0.9.0.0 (2023-09-19)

Update `netaddr` to `0.9.0` (#10732)

## 0.8.0.9 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.8.0.8 (2023-04-13)

Style: prefer `type[Foo | Bar]` over `type[Foo] | type[Bar]` (#10039)

## 0.8.0.7 (2023-03-27)

Add defaults for third-party stubs M-O (#9956)

## 0.8.0.6 (2023-02-22)

Update `Unused` parameters in `stubs/` (#9704)

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 0.8.0.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.8.0.4 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.8.0.3 (2023-02-09)

Use `_typeshed.FileDescriptorOrPath` in stubs (#9695)

## 0.8.0.2 (2023-02-07)

Enable flake8-pyi's Y037 (#9686)

## 0.8.0.1 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 0.8.0.0 (2023-01-07)

Add stubs for netaddr (#9431)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

